@@ -18,6 +18,12 @@ from scouttypes.protected import SignedUrlResponse
 # Exposing CLI components
 from .cli import ScoutCLI
 
+from .crawlers.crawlers import crawlers, Crawler, CrawlerConfiguration
+from .crawlers.indexers import indexers, Indexer
+
+from .agents.scout_agent import ScoutAgent
+from .agents.scout_agent_runner import ScoutAgentRunner
+
 __all__ = [
     # API components
     "ScoutAPI",
@@ -37,4 +43,11 @@ __all__ = [
     "AbstractDocumentChunker",
     "AudioTranscriptionResponse",
     "SignedUrlResponse",
+    "indexers",
+    "Indexer",
+    "crawlers",
+    "Crawler",
+    "CrawlerConfiguration",
+    "ScoutAgent",
+    "ScoutAgentRunner",
 ]
