@@ -4,6 +4,7 @@ from .api import ScoutAPI, ResponseFormatType
 from .assistants import AssistantsAPI, AssistantData, AssistantDataList
 from .conversations import ConversationsAPI
 from .audio import AudioAPI
+from .image import ImageAPI
 from .utils import UtilsAPI
 from .types.assistants import (
     AssistantResponse,
@@ -34,6 +35,7 @@ __all__ = [
     "deprecated",
     "ConversationsAPI",
     "AudioAPI",
+    "ImageAPI",
     "UtilsAPI",
     # assistants
     "AssistantsAPI",
