@@ -3,6 +3,7 @@ from typing import Optional, Any, Type, Generic, cast, TypeVar
 from pydantic import BaseModel
 
 from .request_utils import RequestUtils
+from .retry_config import RetryConfig, create_retry_strategy, retry_on_api_errors
 from scouttypes.constants import VariableNames
 from scouttypes.chat import (
     ChatCompletionResponse,
@@ -58,7 +59,6 @@ from .types.assistants import (
     AssistantResponse,
 )
 
-DEFAULT_MODEL = "gpt-4o"
 
 # Create generic type variables for request and response
 RequestType = TypeVar("RequestType", bound=BaseModel)
@@ -97,6 +97,7 @@ class ScoutAPI:
         self,
         base_url: Optional[str] = None,
         api_access_token: Optional[str] = None,
+        retry_config: Optional[RetryConfig] = None,
     ) -> None:
         self._base_url = base_url or scout.context.get(VariableNames.SCOUT_API_URL)
         if self._base_url is None or self._base_url == "":
@@ -117,14 +118,30 @@ class ScoutAPI:
             "Content-Type": "application/json",
         }
 
+        # Create retry strategy from config or use default
+        if retry_config is not None:
+            # Empty dict means no retries
+            if not retry_config:
+                self._retry_strategy = create_retry_strategy(max_attempts=0)
+            else:
+                self._retry_strategy = create_retry_strategy(**retry_config)
+        else:
+            self._retry_strategy = retry_on_api_errors
+
         # Initialize specialized API clients
-        self.chat = ChatAPI(self._base_url, self._headers)
-        self.assistants = AssistantsAPI(self._base_url, self._headers)
-        self.conversations = ConversationsAPI(self._base_url, self._headers)
-        self.utils = UtilsAPI(self._base_url, self._headers)
-        self.audio = AudioAPI(self._base_url, self._headers)
-        self.image = ImageAPI(self._base_url, self._headers)
-        self.protected = ProtectedAPI(self._base_url, self._headers)
+        self.chat = ChatAPI(self._base_url, self._headers, self._retry_strategy)
+        self.assistants = AssistantsAPI(
+            self._base_url, self._headers, self._retry_strategy
+        )
+        self.conversations = ConversationsAPI(
+            self._base_url, self._headers, self._retry_strategy
+        )
+        self.utils = UtilsAPI(self._base_url, self._headers, self._retry_strategy)
+        self.audio = AudioAPI(self._base_url, self._headers, self._retry_strategy)
+        self.image = ImageAPI(self._base_url, self._headers, self._retry_strategy)
+        self.protected = ProtectedAPI(
+            self._base_url, self._headers, self._retry_strategy
+        )
 
     # Generic requests
     def get(
@@ -155,6 +172,7 @@ class ScoutAPI:
             url=f"{self._base_url}{url}",
             headers=self._headers,
             params=request_data,
+            retry_strategy=self._retry_strategy,
         )
 
         validated_data = get_validated_data(response, response_model)
@@ -186,7 +204,10 @@ class ScoutAPI:
         request_data = data.model_dump() if isinstance(data, BaseModel) else data
 
         response, status_code = RequestUtils.put(
-            url=f"{self._base_url}{url}", headers=self._headers, payload=request_data
+            url=f"{self._base_url}{url}",
+            headers=self._headers,
+            payload=request_data,
+            retry_strategy=self._retry_strategy,
         )
 
         validated_data = get_validated_data(response, response_model)
@@ -228,12 +249,14 @@ class ScoutAPI:
                 headers=local_headers,
                 data=request_data,
                 files=files,
+                retry_strategy=self._retry_strategy,
             )
         else:
             response, status_code = RequestUtils.post(
                 url=f"{self._base_url}{url}",
                 headers=self._headers,
                 json_payload=request_data,
+                retry_strategy=self._retry_strategy,
             )
 
         validated_data = get_validated_data(response, response_model)
@@ -260,6 +283,7 @@ class ScoutAPI:
         response, status_code = RequestUtils.delete(
             url=f"{self._base_url}{url}",
             headers=self._headers,
+            retry_strategy=self._retry_strategy,
         )
 
         validated_data = get_validated_data(response, response_model)
@@ -943,6 +967,7 @@ class ScoutAPI:
         response, status_code = RequestUtils.get(
             url=f"{self._base_url}/api/protected/{path}",
             headers=self._headers,
+            retry_strategy=self._retry_strategy,
         )
 
         return SignedUrlResponse.model_validate(response)
