@@ -1,5 +1,5 @@
 import mimetypes
-from typing import Optional, Type, Any, overload, List, TypeVar
+from typing import Optional, Type, Any, overload, List, TypeVar, Callable
 from pydantic import BaseModel
 from .request_utils import RequestUtils
 from scouttypes.assistants import (
@@ -28,9 +28,10 @@ from .utils import get_validated_data
 
 
 class AssistantsAPI:
-    def __init__(self, base_url: str, headers: dict) -> None:
+    def __init__(self, base_url: str, headers: dict, retry_strategy: Callable) -> None:
         self._base_url = base_url
         self._headers = headers
+        self._retry_strategy = retry_strategy
 
     def create(
         self,
@@ -94,6 +95,7 @@ class AssistantsAPI:
             url=f"{self._base_url}/api/assistants/",
             headers=self._headers,
             json_payload=payload,
+            retry_strategy=self._retry_strategy,
         )
 
         return AssistantInfoResponse.model_validate(response)
@@ -142,6 +144,7 @@ class AssistantsAPI:
             url=f"{self._base_url}/api/assistants/{assistant_id}",
             headers=self._headers,
             json_payload=update_request.model_dump(exclude_none=True),
+            retry_strategy=self._retry_strategy,
         )
 
         return AssistantInfoResponse.model_validate(response)
@@ -157,7 +160,9 @@ class AssistantsAPI:
             AssistantInfoResponse: The assistant object retrieved from the API.
         """
         response, status_code = RequestUtils.get(
-            url=f"{self._base_url}/api/assistants/{assistant_id}", headers=self._headers
+            url=f"{self._base_url}/api/assistants/{assistant_id}",
+            headers=self._headers,
+            retry_strategy=self._retry_strategy,
         )
 
         return AssistantInfoResponse.model_validate(response)
@@ -170,7 +175,9 @@ class AssistantsAPI:
             List[AssistantPublicResponse]: A list of assistant objects retrieved from the API.
         """
         response, status_code = RequestUtils.get(
-            url=f"{self._base_url}/api/assistants", headers=self._headers
+            url=f"{self._base_url}/api/assistants",
+            headers=self._headers,
+            retry_strategy=self._retry_strategy,
         )
 
         return [
@@ -190,6 +197,7 @@ class AssistantsAPI:
         response, status_code = RequestUtils.delete(
             url=f"{self._base_url}/api/assistants/{assistant_id}",
             headers=self._headers,
+            retry_strategy=self._retry_strategy,
         )
         return AssistantDeleteResponse.model_validate(response)
 
@@ -221,6 +229,7 @@ class AssistantsAPI:
                 url=f"{self._base_url}/api/assistants/{assistant_id}/avatar/upload",
                 headers=local_headers,
                 files=files,
+                retry_strategy=self._retry_strategy,
             )
         return AssistantUploadImageResponse.model_validate(response)
 
@@ -259,6 +268,7 @@ class AssistantsAPI:
                 headers=local_headers,
                 files=files,
                 data=data,
+                retry_strategy=self._retry_strategy,
             )
         return AssistantFileUploadResponse.model_validate(response)
 
@@ -278,6 +288,7 @@ class AssistantsAPI:
         response, status_code = RequestUtils.get(
             url=f"{self._base_url}/api/assistants/{assistant_id}/files",
             headers=self._headers,
+            retry_strategy=self._retry_strategy,
         )
         return [AssistantFile.model_validate(file) for file in response]
 
@@ -307,6 +318,7 @@ class AssistantsAPI:
             url=f"{self._base_url}/api/assistants/{assistant_id}/files/{file_uid}",
             headers=self._headers,
             payload=data,
+            retry_strategy=self._retry_strategy,
         )
         return AssistantFileEditResponse.model_validate(response)
 
@@ -328,6 +340,7 @@ class AssistantsAPI:
         response, status_code = RequestUtils.delete(
             url=f"{self._base_url}/api/assistants/{assistant_id}/files/{file_uid}",
             headers=self._headers,
+            retry_strategy=self._retry_strategy,
         )
         return AssistantResponse.model_validate(response)
 
@@ -354,6 +367,7 @@ class AssistantsAPI:
             url=f"{self._base_url}/api/assistants/{assistant_id}/search",
             headers=self._headers,
             json_payload={"query": query, "strategy": strategy, "where": where},
+            retry_strategy=self._retry_strategy,
         )
         return [AssistantSearchDataResponse.model_validate(item) for item in response]
 
@@ -380,6 +394,7 @@ class AssistantsAPI:
             url=f"{self._base_url}/api/assistants/{assistant_id}/data",
             headers=self._headers,
             json_payload={"data": data_list},
+            retry_strategy=self._retry_strategy,
         )
         return CreateAssistantDataResponse.model_validate(response)
 
@@ -408,6 +423,7 @@ class AssistantsAPI:
             url=f"{self._base_url}/api/assistants/{assistant_id}/data/{data_id}",
             headers=self._headers,
             payload={"metadata": metadata, "content": content, "embedding": embedding},
+            retry_strategy=self._retry_strategy,
         )
         return AssistantDataUpdateResponse.model_validate(response)
 
@@ -428,6 +444,7 @@ class AssistantsAPI:
             url=f"{self._base_url}/api/assistants/{assistant_id}/data",
             headers=self._headers,
             params=where,
+            retry_strategy=self._retry_strategy,
         )
         return QueryAssistantDataResponse.model_validate(response).root
 
@@ -455,6 +472,7 @@ class AssistantsAPI:
             url=f"{self._base_url}/api/assistants/{assistant_id}/data",
             headers=self._headers,
             json_payload={"where": where, "id": id},
+            retry_strategy=self._retry_strategy,
         )
         return DeleteAssistantDataResponse.model_validate(response)
 
@@ -534,9 +552,10 @@ class AssistantsAPI:
             headers=self._headers,
             json_payload=request_data,
             params=params,
+            retry_strategy=self._retry_strategy,
         )
 
-        return get_validated_data(response.get("result", {}), response_model)
+        return get_validated_data(response.get("result", response), response_model)
 
     def get_functions(self, assistant_id: str) -> AssistantCustomFunctionsResponse:
         """
@@ -551,5 +570,6 @@ class AssistantsAPI:
         response, status_code = RequestUtils.get(
             url=f"{self._base_url}/api/assistants/{assistant_id}/functions",
             headers=self._headers,
+            retry_strategy=self._retry_strategy,
         )
         return AssistantCustomFunctionsResponse.model_validate(response)
