@@ -17,13 +17,12 @@ from scouttypes.conversations import (
 
 ChatCompletionResponseType = TypeVar("ChatCompletionResponseType", bound=BaseModel)
 
-DEFAULT_MODEL = "gpt-4o"
-
 
 class ChatAPI:
-    def __init__(self, base_url: str, headers: dict) -> None:
+    def __init__(self, base_url: str, headers: dict, retry_strategy: Callable) -> None:
         self._base_url = base_url
         self._headers = headers
+        self._retry_strategy = retry_strategy
 
     @overload
     def completion(
@@ -128,7 +127,7 @@ class ChatAPI:
 
         request_payload = ChatCompletionRequest(
             messages=messages,
-            model=model or DEFAULT_MODEL,
+            model=model,
             assistant_id=assistant_id,
             stream=stream,
             allowed_tools=allowed_tools,
@@ -147,6 +146,7 @@ class ChatAPI:
             headers=self._headers,
             json_payload=json_payload,
             stream=stream,
+            retry_strategy=self._retry_strategy,
         )
 
         if stream:
@@ -306,7 +306,7 @@ class ChatAPI:
             # Call completion API without tools to avoid infinite recursion
             request_payload = ChatCompletionRequest(
                 messages=conversation_messages,
-                model=model or DEFAULT_MODEL,
+                model=model,
                 assistant_id=assistant_id,
                 stream=current_stream,
                 allowed_tools=allowed_tools,
@@ -325,6 +325,7 @@ class ChatAPI:
                 headers=self._headers,
                 json_payload=json_payload,
                 stream=current_stream,
+                retry_strategy=self._retry_strategy,
             )
 
             if current_stream:
@@ -464,7 +465,7 @@ class ChatAPI:
         # Create request payload
         request_payload = ChatCompletionRequest(
             messages=conversation_messages,
-            model=model or DEFAULT_MODEL,
+            model=model,
             assistant_id=assistant_id,
             stream=True,
             allowed_tools=allowed_tools,
@@ -479,7 +480,7 @@ class ChatAPI:
             chat_api=self,
             conversation_messages=conversation_messages,
             tools=tools,
-            model=model or DEFAULT_MODEL,
+            model=model,
             assistant_id=assistant_id,
             debug=debug,
             llm_args=final_llm_args,
