@@ -306,13 +306,60 @@ class ScoutFunctionDecorator:
                 project_dir = os.path.dirname(os.path.abspath(file_path))
                 sys.path.insert(0, project_dir)
 
-                spec = importlib.util.spec_from_file_location(module_name, module_path)
-                if spec and spec.loader:
-                    module = importlib.util.module_from_spec(spec)
-                    spec.loader.exec_module(module)
-
-                if project_dir in sys.path:
-                    sys.path.remove(project_dir)
+                try:
+                    spec = importlib.util.spec_from_file_location(module_name, module_path)
+                    if spec and spec.loader:
+                        module = importlib.util.module_from_spec(spec)
+                        spec.loader.exec_module(module)
+                except SyntaxError as e:
+                    error_msg = (
+                        f"❌ Syntax Error in '{os.path.basename(file_path)}'\n"
+                        f"   File: {file_path}\n"
+                        f"   Line: {e.lineno}\n"
+                        f"   Error: {e.msg}\n"
+                    )
+                    if e.text:
+                        error_msg += f"   Code: {e.text.strip()}\n"
+                    error_msg += f"\n💡 Fix the syntax error on line {e.lineno} and try again."
+                    raise SyntaxError(error_msg) from e
+                except ModuleNotFoundError as e:
+                    missing_module = str(e).split("'")[1] if "'" in str(e) else str(e)
+                    error_msg = (
+                        f"❌ Module Not Found in '{os.path.basename(file_path)}'\n"
+                        f"   File: {file_path}\n"
+                        f"   Missing module: {missing_module}\n"
+                        f"\n💡 Install the required package with: pip install {missing_module}\n"
+                        f"   Or add it to your requirements.txt file."
+                    )
+                    raise ModuleNotFoundError(error_msg) from e
+                except ImportError as e:
+                    error_msg = (
+                        f"❌ Import Error in '{os.path.basename(file_path)}'\n"
+                        f"   File: {file_path}\n"
+                        f"   Error: {str(e)}\n"
+                        f"\n💡 Check your import statements and ensure all dependencies are installed."
+                    )
+                    raise ImportError(error_msg) from e
+                except AttributeError as e:
+                    error_msg = (
+                        f"❌ Attribute Error in '{os.path.basename(file_path)}'\n"
+                        f"   File: {file_path}\n"
+                        f"   Error: {str(e)}\n"
+                        f"\n💡 Check that all referenced attributes and methods exist."
+                    )
+                    raise AttributeError(error_msg) from e
+                except Exception as e:
+                    error_msg = (
+                        f"❌ Error loading '{os.path.basename(file_path)}'\n"
+                        f"   File: {file_path}\n"
+                        f"   Error type: {e.__class__.__name__}\n"
+                        f"   Error: {str(e)}\n"
+                        f"\n💡 Review the error message above and fix the issue in your code."
+                    )
+                    raise type(e)(error_msg) from e
+                finally:
+                    if project_dir in sys.path:
+                        sys.path.remove(project_dir)
 
     def _set_context(self, context: dict) -> None:
         self._context = context
