@@ -1,11 +1,13 @@
+from typing import Callable
 from .request_utils import RequestUtils
 from scouttypes.protected import SignedUrlResponse
 
 
 class ProtectedAPI:
-    def __init__(self, base_url: str, headers: dict) -> None:
+    def __init__(self, base_url: str, headers: dict, retry_strategy: Callable) -> None:
         self._base_url = base_url
         self._headers = headers
+        self._retry_strategy = retry_strategy
 
     def get_signed_url(self, path: str) -> SignedUrlResponse:
         """
@@ -30,6 +32,7 @@ class ProtectedAPI:
         response, status_code = RequestUtils.get(
             url=f"{self._base_url}/api{final_path}",
             headers=self._headers,
+            retry_strategy=self._retry_strategy,
         )
 
         return SignedUrlResponse.model_validate(response)
