@@ -1,3 +1,4 @@
+from typing import Optional
 from pydantic import BaseModel
 
 
@@ -7,6 +8,8 @@ class AssistantFile(BaseModel):
     description: str = ""
     status: str = ""
     content_type: str = ""
+    type: str = ""
+    functions_schema: Optional[dict] = None
 
 
 class AssistantFileUploadResponse(BaseModel):
