@@ -6,3 +6,5 @@ class VariableNames(StrEnum):
     SCOUT_API_ACCESS_TOKEN = "SCOUT_API_ACCESS_TOKEN"
     SCOUT_ASSISTANT_ID = "SCOUT_ASSISTANT_ID"
     SCOUT_CONVERSATION_ID = "SCOUT_CONVERSATION_ID"
+    SCOUT_CODE_MODEL_ID = "SCOUT_CODE_MODEL_ID"
+    SCOUT_ACCESS_TOKENS = "SCOUT_ACCESS_TOKENS"
