@@ -1,4 +1,5 @@
 from pydantic import BaseModel, ConfigDict
+from typing import Optional, Dict, Any
 
 
 class AssistantFile(BaseModel):
@@ -8,6 +9,8 @@ class AssistantFile(BaseModel):
     description: str = ""
     status: str = ""
     content_type: str = ""
+    type: str = ""
+    functions_schema: Optional[Dict[str, Any]] = None
 
 
 __all__ = ["AssistantFile"]
