@@ -7,7 +7,7 @@ class ChatCompletionRequest(BaseModel):
     model_config = ConfigDict(extra="allow")
     messages: List[ConversationMessage]
     assistant_id: Optional[str] = None
-    model: str
+    model: Optional[str] = None
     stream: bool = False
     response_interface: Optional[str] = None
     llm_args: Optional[dict] = None
